@@ -1,4 +1,8 @@
-__version__ = '0.0.19'  # print(ultralytics.__version__)
+__version__ = '0.0.20'  # print(ultralytics.__version__)
+
+from .yolov5_wrapper import clone_yolo
+
+clone_yolo()
 
 
 def login():
