@@ -5,7 +5,7 @@ import requests
 from .config import HUB_API_ROOT
 from .utils.general import colorstr
 
-PREFIX = colorstr('Ultralytics HUB: ')
+PREFIX = colorstr('Ultralytics: ')
 
 
 class HUBLogger:
