@@ -3,18 +3,14 @@
 from .auth import Auth
 from .config import BY_PASS_LOGIN
 from .trainer import Trainer
-from .yolov5_wrapper import verify_install
+from .yolov5_wrapper import clone_yolo
 
 AUTH = Auth()
 
 
-def setup_yolo() -> None:
-    """Checks if yolov5 exists and if not clones it"""
-    verify_install()
-
-
 def train_model() -> None:
     """Starts training from next in queue"""
+    clone_yolo()
     trainer = Trainer(None, AUTH)  # No model so next in train queue is fetched
     if trainer.model is not None:
         trainer.start()
@@ -32,7 +28,7 @@ def connect_to_hub(password=False) -> bool:
 
 
 def main():
-    setup_yolo()
+    clone_yolo()
     if BY_PASS_LOGIN:
         AUTH.sign_in_with_email_and_password("kalen.michael@ultralytics.com", "7654321")
         if AUTH.idToken:
