@@ -11,9 +11,9 @@ PREFIX = colorstr('Ultralytics: ')
 class Trainer:
     def __init__(self, model_id, auth):
         self.auth = auth
-        self.model = self._getModel(model_id)
+        self.model = self._get_model(model_id)
         if self.model is not None:
-            self._connectCallbacks()
+            self._connect_callbacks()
 
     def _get_model_by_id(self):
         # return a specific model
@@ -23,7 +23,7 @@ class Trainer:
         # return next model in queue
         return
 
-    def _getModel(self, model_id):
+    def _get_model(self, model_id):
         """
         Returns model from database by id
         """
@@ -35,7 +35,7 @@ class Trainer:
             r = requests.post(api_url, json=payload)
             res = r.json()
 
-            if res["data"] == None:
+            if res["data"] is None:
                 print(f"\n{PREFIX}ERROR: Unable to fetch model")
                 return None  # Cannot train without model
             elif not res["data"]:
@@ -46,14 +46,12 @@ class Trainer:
                     "id"]  # Append id as it may be fetched from queue and unknown
                 return res["data"]
         except requests.exceptions.ConnectionError:
-            print(
-                f'\n{PREFIX}ERROR: The HUB server is not online. Please try again later.'
-            )
+            print(f'\n{PREFIX}ERROR: The HUB server is not online. Please try again later.')
             return None
             # sys.exit(141)  # TODO: keep this 141 sys exit error code?
 
-    def _connectCallbacks(self):
-        callback_handler = YOLOv5.newCallbackHandler()
+    def _connect_callbacks(self):
+        callback_handler = YOLOv5.new_callback_handler()
         hub_logger = HUBLogger(self.model_id, self.auth)
         callback_handler.register_action("on_model_save", "HUB",
                                          hub_logger.on_model_save)
